library(dplyr)
library(survival)
library(ggplot2)
library(flexsurv)
library(survminer)

# Loading the CSV file
dat <- read.csv('C:/Users/beb/NILU/Evert Bouman - RubberRoad/Data modeling/vegdekke.csv', header = TRUE, sep = ",", dec = ".")

# Add new columns to the dataframe
# lifetime of pavements from the year that they have been placed until they have been removed
pave_year = dat$X_TilDate - dat$X_PavDat
dat$n_year <- pave_year

# Removing rows from the dataframe that contain the lifetime difference that are less than 2 years 
dat <- subset(dat, dat$n_year > 2) 

# allocating binary values for pavements that last longer or shorter than 40 years (there is not strong ...
# rational on why it is 40 rather than any other duration)
dat$event <- ifelse(dat$n_year>=40, 0, 1)

################# Traffic class 1 #################

TC1 <- filter(dat, AADT_Klass == "1" & between(n_year,1,25))
TC1 <- TC1 %>% filter(!is.na(TC1$NS_2288) & !is.na(TC1$TYKK_1642))

# Removing variables (i.e., asphalt mixes and dimensions that are not of interest in this investigation) 
TC1 <- TC1[ which(TC1$TYPE_1216!='Asfalt' & TC1$TYPE_1216!='Asfaltskumgrus' &
                  TC1$TYPE_1216!='Dobbel overflatebehandling' & TC1$TYPE_1216!='Drensasfalt' &
                  TC1$TYPE_1216!='Gjenbruksasfalt' & TC1$TYPE_1216!='Grus' &
                  TC1$TYPE_1216!='Støpeasfalt' &  TC1$TYPE_1216!='Topeka' &
                  TC1$TYPE_1216!='Asfaltert grus' &  TC1$TYPE_1216!='Asfaltløsningsgrus' &
                  TC1$TYPE_1216!='Dobbel overflatebehandling grus' &  TC1$TYPE_1216!='Emulsjonsgrus' &
                  TC1$TYPE_1216!='Enkel overflatebehandling' &  TC1$TYPE_1216!='Enkel overflatebehandling grus' &  
                  TC1$TYPE_1216!='Oljegrus' &    
                  TC1$TYPE_1216!='Tynndekke' & TC1$NS_2288!=2 & TC1$NS_2288!=4 &
                  TC1$MAFB_5134>=40 & TC1$MAFB_5134<=60),]
table(TC1$TYPE_1216)


# Change some of variables to factors 
TC1$NS_2288 <- factor(TC1$NS_2288)

# check if the corresponding variable is factor or not
is.factor(TC1$NS_2288)


cox_TC1 <- coxph(Surv(n_year, event) ~ strata(TYPE_1216),# +
                    #relevel(factor(NS_2288),"11"),
                  data=TC1)

summary(cox_TC1)


fit_cox_TC1 <- flexsurvreg(Surv(n_year, event) ~ strata(TYPE_1216),# +
                             #relevel(factor(NS_2288),"8"),
                           data = TC1, dist = "Weibull")

summary(fit_cox_TC1)

# creating a basedata
cox_TC1_df <- data.frame(NS_2288="11")

# fitting survival output to the created basedata outputs
kaplan_TC1 <- survfit(cox_TC1, newdata=cox_TC1_df)


ggsurvplot(kaplan_TC1, data = TC1)
ggsurvplot(fit_cox_TC1, data = TC1)


################# Traffic class 2 #################

TC2 <- filter(dat, AADT_Klass == "2" & between(n_year,1,25))
TC2 <- TC2 %>% filter(!is.na(TC2$NS_2288) & !is.na(TC2$TYKK_1642))

TC2 <- TC2[ which(TC2$TYPE_1216!='Asfalt' & TC2$TYPE_1216!='Asfaltskumgrus' &
                    TC2$TYPE_1216!='Dobbel overflatebehandling' & TC2$TYPE_1216!='Drensasfalt' &
                    TC2$TYPE_1216!='Gjenbruksasfalt' & TC2$TYPE_1216!='Grus' &
                    TC2$TYPE_1216!='Støpeasfalt' &  TC2$TYPE_1216!='Topeka' &
                    TC2$TYPE_1216!='Tynndekke' & TC2$TYPE_1216!='Valsebetong' &
                    TC2$TYPE_1216!='Asfaltert grus' & TC2$TYPE_1216!='Asfaltløsningsgrus' &
                    TC2$TYPE_1216!='Dobbel overflatebehandling grus' & TC2$TYPE_1216!='Enkel overflatebehandling grus' &
                    TC2$TYPE_1216!='Oljegrus' & 
                    TC2$NS_2288!=4 & TC2$NS_2288!=6 & TC2$NS_2288!=14 &
                    TC2$MAFB_5134>=40 & TC2$MAFB_5134<=60),]

table(TC2$NS_2288)
table(TC2$TYPE_1216)

# Change some of variables to factors 
TC2$NS_2288 <- factor(TC2$NS_2288)
is.factor(TC2$NS_2288)

cox_TC2 <- coxph(Surv(n_year, event) ~ strata(TYPE_1216),# +
                   #relevel(factor(NS_2288),"8"),
                 data=TC2)

summary(cox_TC2)
fit_cox_TC2 <- flexsurvreg(Surv(n_year, event) ~ strata(TYPE_1216),# +
                             #relevel(factor(NS_2288),"8"),
                           data = TC2, dist = "weibull")

summary(fit_cox_TC2)

cox_TC2_df <- data.frame(NS_2288="8")

kaplan_TC2 <- survfit(cox_TC2, newdata=cox_TC2_df)

ggsurvplot(kaplan_TC2, data = TC2)
ggsurvplot(fit_cox_TC2, data = TC2)

################# Traffic class 3 #################
TC3 <- filter(dat, AADT_Klass == "3" & between(n_year,1,25))
TC3 <- TC3 %>% filter(!is.na(TC3$NS_2288) & !is.na(TC3$TYKK_1642))

TC3 <- TC3[ which(TC3$TYPE_1216!='Asfalt' & TC3$TYPE_1216!='Dobbel overflatebehandling' &
                    TC3$TYPE_1216!='Dobbel overflatebehandling grus' & TC3$TYPE_1216!='Drensasfalt' &
                    TC3$TYPE_1216!='Enkel overflatebehandling grus' & TC3$TYPE_1216!='Gjenbruksasfalt' &
                    TC3$TYPE_1216!='Støpeasfalt' &  TC3$TYPE_1216!='Topeka' &
                    TC3$TYPE_1216!='Tynndekke' & TC3$TYPE_1216!='Valsebetong' &
                    TC3$TYPE_1216!='Asfaltert grus' & TC3$TYPE_1216!='Asfaltløsningsgrus' &
                    TC3$TYPE_1216!='Emulsjonsgrus' & TC3$TYPE_1216!='Enkel overflatebehandling' &
                    TC3$TYPE_1216!='Oljegrus' & 
                    TC3$NS_2288!=2 & TC3$NS_2288!=14 & TC3$NS_2288!=32 &
                    TC3$MAFB_5134>=40 & TC3$MAFB_5134<=60),]

table(TC3$NS_2288)
table(TC3$TYPE_1216)

# Change some of variables to factors 
TC3$NS_2288 <- factor(TC3$NS_2288)
is.factor(TC3$NS_2288)

cox_TC3 <- coxph(Surv(n_year, event) ~ strata(TYPE_1216),# +
                   #relevel(factor(NS_2288),"8"),
                 data=TC3)

summary(cox_TC3)
fit_cox_TC3 <- flexsurvreg(Surv(n_year, event) ~ strata(TYPE_1216),# +
                             #relevel(factor(NS_2288),"8"),
                           data = TC3, dist = "weibull")

cox_TC3_df <- data.frame(NS_2288="8")

kaplan_TC3 <- survfit(cox_TC3, newdata=cox_TC3_df)

ggsurvplot(kaplan_TC3, data = TC3)
ggsurvplot(fit_cox_TC3, data = TC3)

################# Traffic class 4 #################
TC4 <- filter(dat, AADT_Klass == "4" & between(n_year,1,25))
TC4 <- TC4 %>% filter(!is.na(TC4$NS_2288) & !is.na(TC4$TYKK_1642))

TC4 <- TC4[ which(TC4$TYPE_1216!='Asfalt' & TC4$TYPE_1216!='Dobbel overflatebehandling' &
                    TC4$TYPE_1216!='Dobbel overflatebehandling grus' &
                    TC4$TYPE_1216!='Enkel overflatebehandling grus' & TC4$TYPE_1216!='Gjenbruksasfalt' &
                    TC4$TYPE_1216!='Støpeasfalt' &  TC4$TYPE_1216!='Topeka' &
                    TC4$TYPE_1216!='Tynndekke' & TC4$TYPE_1216!='Brostein' &
                    TC4$TYPE_1216!='Betong' & TC4$TYPE_1216!='Asfaltert grus' &
                    TC4$TYPE_1216!='Asfaltløsningsgrus' & TC4$TYPE_1216!='Drensasfalt' &
                    TC4$TYPE_1216!='Emulsjonsgrus' & TC4$TYPE_1216!='Enkel overflatebehandling' &
                    TC4$TYPE_1216!='Oljegrus' & TC4$TYPE_1216!='Mykasfalt' &
                    TC4$NS_2288!=32 &
                    TC4$MAFB_5134>=40 & TC4$MAFB_5134<=60),]

table(TC4$NS_2288)
table(TC4$TYPE_1216)

# Change some of variables to factors 
TC4$NS_2288 <- factor(TC4$NS_2288)
is.factor(TC4$NS_2288)

cox_TC4 <- coxph(Surv(n_year, event) ~ strata(TYPE_1216),# +
                   #relevel(factor(NS_2288),"8"),
                 data=TC4)

summary(cox_TC4)
fit_cox_TC4 <- flexsurvreg(Surv(n_year, event) ~ strata(TYPE_1216),# +
                             #relevel(factor(NS_2288),"8"),
                           data = TC4, dist = "weibull")

cox_TC4_df <- data.frame(NS_2288="8")

kaplan_TC4 <- survfit(cox_TC4, newdata=cox_TC4_df)

ggsurvplot(kaplan_TC4, data = TC4)
ggsurvplot(fit_cox_TC4, data = TC4)

################# Traffic class 5 #################

TC5 <- filter(dat, AADT_Klass == "5" & between(n_year,1,20))
TC5 <- TC5 %>% filter(!is.na(TC5$NS_2288) & !is.na(TC5$TYKK_1642))

TC5 <- TC5[ which(TC5$TYPE_1216!='Asfalt' & TC5$TYPE_1216!='Dobbel overflatebehandling' &
                    TC5$TYPE_1216!='Dobbel overflatebehandling grus' & TC5$TYPE_1216!='Emulsjonsgrus' &
                    TC5$TYPE_1216!='Enkel overflatebehandling grus' & TC5$TYPE_1216!='Gjenbruksasfalt' &
                    TC5$TYPE_1216!='Støpeasfalt' & TC5$TYPE_1216!='Slamasfalt' &  
                    TC5$TYPE_1216!='Tynndekke' & TC5$TYPE_1216!='Oljegrus' &
                    TC5$TYPE_1216!='Asfaltløsningsgrus' & TC5$TYPE_1216!='Enkel overflatebehandling' &
                    TC5$NS_2288!=14),]

table(TC5$NS_2288)
table(TC5$TYPE_1216)

# Change some of variables to factors 
TC5$NS_2288 <- factor(TC5$NS_2288)
is.factor(TC5$NS_2288)

cox_TC5 <- coxph(Surv(n_year, event) ~ strata(TYPE_1216) +
                   relevel(factor(NS_2288),"8"),
                 data=TC5)

summary(cox_TC5)
fit_cox_TC5 <- flexsurvreg(Surv(n_year, event) ~ strata(TYPE_1216) +
                             relevel(factor(NS_2288),"8"),
                           data = TC5, dist = "weibull")

cox_TC5_df <- data.frame(NS_2288="8")

kaplan_TC5 <- survfit(cox_TC5, newdata=cox_TC5_df)

ggsurvplot(kaplan_TC5, data = TC5)
ggsurvplot(fit_cox_TC5, data = TC5)


################# Traffic class 6 #################

dat <- read.csv('./MFA/Levetider.csv', header = TRUE, sep = ",", dec = ".")
TC6 <- filter(dat, X_T_klass == "6" & between(X_Year,1,51))
TC6 <- TC6 %>%
  mutate(zone = ifelse(gridcode == 0 | gridcode == 1, "A" ,
                       ifelse(gridcode == 10, "B" ,
                              ifelse(gridcode == 100 ,"C" , NA ))))

fit_cox_TC6 <- flexsurvreg(Surv(X_Year, X_Event) ~ 1 , data = TC6, dist = "weibull")

ggsurvplot(fit_cox_TC6)


sh <- fit_cox_TC6$res[1:1]
sh_LB <- fit_cox_TC6$res[3:3]
sh_UB <- fit_cox_TC6$res[5:5]
sc <- fit_cox_TC6$res[2:2]
sc_LB <- fit_cox_TC6$res[4:4]
sc_UB <- fit_cox_TC6$res[6:6]

Wb <- matrix(c(sh, sc),nrow = 2)
Wb_LB <- matrix(c(sh_LB, sc_LB),nrow = 2)
Wb_UB <- matrix(c(sh_UB, sc_UB),nrow = 2)

write.csv(Wb, file = "./MFA/WB/TC6_Par_Base.csv")
write.csv(Wb_LB, file = "./MFA/WB/TC6_Par_LB.csv")
write.csv(Wb_UB, file = "./MFA/WB/TC6_Par_UB.csv")

write.csv(summary(fit_cox_TC6, type = 'median'), file = "./MFA/WB/TC6_median.csv")

################# Traffic class 7 #################
dat <- read.csv('./MFA/Levetider.csv', header = TRUE, sep = ",", dec = ".")
TC7 <- filter(dat, X_T_klass == "7" & between(X_Year,1,51))
TC7 <- TC7 %>%
  mutate(zone = ifelse(gridcode == 0 | gridcode == 1, "A" ,
                       ifelse(gridcode == 10, "B" ,
                              ifelse(gridcode == 100 ,"C" , NA ))))

TC7_f <- TC7[ which(TC7$TYPE_1216!='Asfalt' & TC7$TYPE_1216!='Drensasfalt' &
                      TC7$TYPE_1216!='Topeka' & TC7$TYPE_1216!='Tynndekke'),]

fit_cox_TC7 <- flexsurvreg(Surv(X_Year, X_Event) ~ 1 , data = TC7_f, dist = "weibull")

ggsurvplot(fit_cox_TC7)
fit_cox_TC7

sh <- fit_cox_TC7$res[1:1]
sh_LB <- fit_cox_TC7$res[3:3]
sh_UB <- fit_cox_TC7$res[5:5]
sc <- fit_cox_TC7$res[2:2]
sc_LB <- fit_cox_TC7$res[4:4]
sc_UB <- fit_cox_TC7$res[6:6]

Wb <- matrix(c(sh, sc),nrow = 2)
Wb_LB <- matrix(c(sh_LB, sc_LB),nrow = 2)
Wb_UB <- matrix(c(sh_UB, sc_UB),nrow = 2)

write.csv(Wb, file = "./MFA/WB/TC7_Par_Base.csv")
write.csv(Wb_LB, file = "./MFA/WB/TC7_Par_LB.csv")
write.csv(Wb_UB, file = "./MFA/WB/TC7_Par_UB.csv")

write.csv(summary(fit_cox_TC7, type = 'median'), file = "./MFA/WB/TC7_median.csv")
